@@ -42,10 +42,13 @@ def askForInput(message, noAsk):
 
 
 def getEnvironmentCmd(conda, scipionHome, scipionEnv, noAsk, create=True):
+
+    cmd = cmdfy("cd %s" % scipionHome)
+
     if conda:
-        cmd = getCondaCmd(scipionEnv, noAsk, create)
+        cmd += getCondaCmd(scipionEnv, noAsk, create)
     else:
-        cmd = getVirtualenvCmd(scipionHome, scipionEnv, create)
+        cmd += getVirtualenvCmd(scipionHome, scipionEnv, create)
 
     return cmd
 
@@ -98,11 +101,11 @@ def cmdfy(cmd, sep=CMD_SEP):
 
 
 def getVirtualenvCmd(scipionHome, scipionEnv, create):
-
-    cmd = cmdfy("cd %s" % scipionHome)
+    cmd = ""
     if create:
         cmd += cmdfy("%s -m virtualenv --python=python3 %s" % (sys.executable,
                                                                scipionEnv))
+
     cmd += cmdfy(getVirtualenvActivationCmd(scipionHome, scipionEnv))
     return cmd
 
@@ -115,9 +118,15 @@ def checkProgram(program, doRaise=True):
     """Check whether `name` is on PATH.
     :param doRaise: (True) - raise an exception if not found otherwise, return empty string """
 
-    from distutils.spawn import find_executable
+    try:
+        from shutil import which
 
-    fullPath = find_executable(program)
+        fullPath = which(program)
+
+    # Python 2 case:
+    except Exception as e:
+        from distutils.spawn import find_executable
+        fullPath = find_executable(program)
 
     if fullPath is None:
         if doRaise:
